==> limny-3.0.0.tar.bz2: limny-3.0.0/langs/en/admin.php <==
<?php

/*
 * admin.php
 *
 * @copyright     Copyright 2009-2011 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

def('LOGIN_TO_ACCOUNT', 'Login to account');
def('USERNAME', 'Username');
def('PASSWORD', 'Password');
def('REMEMBER_ME_ON_THIS_COMPUTER', 'Remember me on this computer');
def('LOGIN', 'Login');
def('I_CANT_ACCESS_MY_ACCOUNT', 'I can\'t access my account');
def('POWERED_BY', 'Powered by');
def('ADMINISTRATION', 'Administration');
def('SETTINGS', 'Settings');
def('USERS_AND_ROLES', 'Users &amp; Roles');
def('APPLICATIONS', 'Applications');
def('CONFIGURATION', 'Configuration');
def('APPEARANCE', 'Appearance');
def('WIDGETS', 'Widgets');
def('LANGUAGES', 'Languages');
def('LOGOUT', 'Logout');
def('AVAILABLE_WIDGETS', 'Available widgets');
def('TITLE', 'Title');
def('CONTENT', 'Content');
def('WIDGET', 'Widget');
def('VISIBILITY', 'Visibility');
def('BACK', 'Back');
def('ALL', 'all');
def('DELETE', 'Delete');
def('INSTALL', 'Install');
def('NAME', 'Name');
def('DESCRIPTION', 'Description');
def('INSTALLED', 'Installed');
def('READY_TO_INSTALL', 'Ready to install');
def('UNINSTALL', 'Uninstall');
def('DEPENDED_ON', 'Depended on');
def('REQUIRED_BY', 'Required by');
def('NOPE', 'Nope');
def('PLEASE_TYPE_YES_IN_THE_FIELD', 'Please type YES in the field');
def('GET_AN_APP', 'Get an app');
def('EDIT', 'Edit');
def('SET_AS_DEFAULT', 'Set as default');
def('OKAY', 'Okay');
def('FILES', 'files');
def('APOSTROPHE_S', '\'s');
def('UPDATE', 'Update');
def('STYLES', 'Styles');
def('OPTION', 'option');
def('OPTIONS', 'options');
def('GENERAL', 'General');
def('HEADER', 'Header');
def('SITE', 'Site');
def('FOR_EXAMPLE', 'e.g.');
def('ALLOWED_HTML_TAGS', 'Allowed HTML tags');
def('URI_MODE', 'URI mode');
def('GET', 'GET');
def('REQUEST_URI', 'REQUEST_URI');
def('PERMALINK', 'Permalink');
def('INCLUDE_SOURCE_IN_PERMALINK_PAGE', 'include source in peremalink page');
def('REDIRECT_TO_SOURCE_PAGE', 'redirect to source page');
def('REWRITE', 'Rewrite');
def('ENABLE', 'enable');
def('DISABLE', 'disable');
def('APPLICATION', 'Application');
def('QUERY', 'Query');
def('CODE', 'Code');
def('USERS', 'Users');
def('ROLES', 'Roles');
def('YES', 'yes');
def('NO', 'no');
def('EMAIL', 'Email');
def('ROLE', 'Role');
def('ADMIN', 'Admin');
def('BAN', 'Ban');
def('PERMISSIONS', 'Permissions');
def('FULL_PRIVILEGE', 'full privilege');
def('PRIVILEGE', 'privilege');
def('PRIVILEGES', 'privileges');
def('NO_PRIVILEGE', 'no privilege');
def('ROWS', 'Rows');
def('USER', 'User');
def('THEME', 'Theme');
def('_DEFAULT_', 'Default');
def('LANGUAGE', 'Language');
def('FILE', 'File');
def('UPLOAD', 'Upload');
def('ADD_NEW_ROLE', 'add new role');
def('MOVE_USERS', 'Move users');
def('IMPORTANT_NOTICE', 'IMPORTANT NOTICE');
def('MOVE_USERS_TO', 'Move users to');
def('MOVE', 'Move');
def('HOST', 'Host');
def('CONNECT_USING_SSL', 'connect using SSL');
def('HOME_DIRECTORY', 'Home Directory');
def('_ON_', 'on');
def('OFF', 'off');
def('REGISTRATION', 'Registration');
def('PAGE_REQUEST_REFUSED', 'Page request refused');
def('NOT_COMPATIBLE', 'not compatible');


def('INFO_1', 'The entry username and password are incorrect.');
def('INFO_2', 'This account has been banned.');
def('INFO_3', 'This account is not an administration account.');
def('INFO_4', 'Registration for new users');
def('INFO_5', 'There is not any application privilege.');
def('INFO_6', 'File not found');
def('INFO_7', 'There is no installed applications');
def('INFO_8', 'There is no uninstalled applications');
def('INFO_9', 'Cannot connect to host');
def('INFO_10', 'Are you sure you want uninstall this application and remove all of it\'s data?');
def('INFO_11', 'You can not uninstall default theme. Please set the other themes as default and try again.');
def('INFO_12', 'This theme is not compatible with this version of Limny.');
def('INFO_13', 'HTML tags which are allowed to use in custom widgets');
def('INFO_14', 'How to be shown URLs?');
def('INFO_15', 'How to be shown permalinks? if you are not sure choose include.');
def('INFO_16', 'Requires mod_rewrite. if you are not sure disable it.');
def('INFO_17', 'What do you want show in home page?');
def('INFO_18', 'an application which launchs in your home page');
def('INFO_19', 'query which you want show in home page');
def('INFO_20', 'a piece of HTML or PHP code which launchs in home page.');
def('INFO_21', 'Username must be contain of a-z and 0-9 characters. You can also user dot (.) and underline (_) characters.');
def('INFO_22', 'This username is already exists. Please choose another one.');
def('INFO_23', 'Invalid email address. Please enter another one.');
def('INFO_24', 'This email is already taken by another user. Please choose another one.');
def('INFO_25', 'This role is already exists. Please choose another one.');
def('INFO_26', 'Are you sure you want delete this user account?');
def('INFO_27', 'Are you sure you want delete this widget?');
def('INFO_28', 'There is no installed languages');
def('INFO_29', 'There is no uninstalled languages');
def('INFO_30', 'Are you sure you want uninstall this language?');
def('INFO_31', 'You don\'t have enough permission to access this page. Please contact to the system administrator.');
def('INFO_32', 'Are you sure you want delete this role and all of users in it?');
def('INFO_33', 'Access to this file failed. Please enter your FTP information to update this file using FTP protocol.');
def('INFO_34', 'It seems GD Library is not installed and. It is necessary for updating this theme.');

?>

==> limny-3.2.1.tar.bz2: limny-3.2.1/langs/en/admin.php <==
<?php

/*
 * admin.php
 *
 * @copyright     Copyright 2009-2012 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

def('LIMNY', 'Limny');
def('LOGIN_TO_ACCOUNT', 'Login to account');
def('USERNAME', 'Username');
def('PASSWORD', 'Password');
def('REMEMBER_ME_ON_THIS_COMPUTER', 'Remember me on this computer');
def('LOGIN', 'Login');
def('I_CANT_ACCESS_MY_ACCOUNT', 'I can\'t access my account');
def('POWERED_BY', 'Powered by');
def('ADMINISTRATION', 'Administration');
def('SETTINGS', 'Settings');
def('USERS_AND_ROLES', 'Users &amp; Roles');
def('APPLICATIONS', 'Applications');
def('CONFIGURATION', 'Configuration');
def('APPEARANCE', 'Appearance');
def('BLOCK', 'Block');
def('BLOCKS', 'Blocks');
def('WIDGETS', 'Widgets');
def('LANGUAGES', 'Languages');
def('LOGOUT', 'Logout');
def('AVAILABLE_WIDGETS', 'Available widgets');
def('TITLE', 'Title');
def('CONTENT', 'Content');
def('WIDGET', 'Widget');
def('VISIBILITY', 'Visibility');
def('BACK', 'Back');
def('ALL', 'all');
def('DELETE', 'Delete');
def('INSTALL', 'Install');
def('NAME', 'Name');
def('DESCRIPTION', 'Description');
def('INSTALLED', 'Installed');
def('READY_TO_INSTALL', 'Ready to install');
def('UNINSTALL', 'Uninstall');
def('DEPENDED_ON', 'Depended on');
def('REQUIRED_BY', 'Required by');
def('NOPE', 'Nope');
def('PLEASE_TYPE_YES_IN_THE_FIELD', 'Please type YES in the field');
def('GET_AN_APP', 'Get an app');
def('EDIT', 'Edit');
def('SET_AS_DEFAULT', 'Set as default');
def('OKAY', 'Okay');
def('FILES', 'files');
def('APOSTROPHE_S', '\'s');
def('UPDATE', 'Update');
def('STYLES', 'Styles');
def('OPTION', 'Option');
def('OPTIONS', 'Options');
def('GENERAL', 'General');
def('HEADER', 'Header');
def('SITE', 'Site');
def('FOR_EXAMPLE', 'e.g.');
def('ALLOWED_HTML_TAGS', 'Allowed HTML tags');
def('URI_MODE', 'URI mode');
def('GET', 'GET');
def('REQUEST_URI', 'REQUEST_URI');
def('PERMALINK', 'Permalink');
def('INCLUDE_SOURCE_IN_PERMALINK_PAGE', 'include source in peremalink page');
def('REDIRECT_TO_SOURCE_PAGE', 'redirect to source page');
def('REWRITE', 'Rewrite');
def('ENABLE', 'enable');
def('DISABLE', 'disable');
def('APPLICATION', 'Application');
def('QUERY', 'Query');
def('CODE', 'Code');
def('USERS', 'Users');
def('ROLES', 'Roles');
def('YES', 'yes');
def('NO', 'no');
def('EMAIL', 'Email');
def('ROLE', 'Role');
def('ADMIN', 'Admin');
def('BAN', 'Ban');
def('PERMISSIONS', 'Permissions');
def('FULL_PRIVILEGE', 'full privilege');
def('PRIVILEGE', 'privilege');
def('PRIVILEGES', 'privileges');
def('NO_PRIVILEGE', 'no privilege');
def('ROWS', 'Rows');
def('USER', 'User');
def('THEME', 'Theme');
def('_DEFAULT_', 'Default');
def('LANGUAGE', 'Language');
def('FILE', 'File');
def('UPLOAD', 'Upload');
def('ADD_NEW_ROLE', 'add new role');
def('MOVE_USERS', 'Move users');
def('IMPORTANT_NOTICE', 'IMPORTANT NOTICE');
def('MOVE_USERS_TO', 'Move users to');
def('MOVE', 'Move');
def('HOST', 'Host');
def('CONNECT_USING_SSL', 'connect using SSL');
def('HOME_DIRECTORY', 'Home Directory');
def('_ON_', 'on');
def('OFF', 'off');
def('REGISTRATION', 'Registration');
def('PAGE_REQUEST_REFUSED', 'Page request refused');
def('NOT_COMPATIBLE', 'not compatible');
def('DEFAULT_VALUES', 'Default values');
def('LOAD_DEFAULT_VALUES', 'Load default values');
def('INSTALL_NEW', 'Install New');
def('MAIN_PAGE', 'Main page');
def('_COLLECTOR_', 's');
def('NONE', 'None');

def('INFO_1', 'The entry username and password are incorrect.');
def('INFO_2', 'This account has been banned.');
def('INFO_3', 'This account is not an administration account.');
def('INFO_4', 'Registration for new users');
def('INFO_5', 'There is not any application privilege.');
def('INFO_6', 'File not found');
def('INFO_7', 'There is no installed applications');
def('INFO_8', 'There is no uninstalled applications');
def('INFO_9', 'Cannot connect to host');
def('INFO_10', 'Are you sure you want uninstall this application and remove all its data?');
def('INFO_11', 'You cannot uninstall default theme. Please set the other theme as default and try again.');
def('INFO_12', 'This theme is not compatible with this version of Limny.');
def('INFO_13', 'HTML tags which are allowed to use in custom widgets');
def('INFO_14', 'How to be shown URLs?');
def('INFO_15', 'How to be shown permalinks? if you are not sure choose include.');
def('INFO_16', 'Requires mod_rewrite. if you are not sure disable it.');
def('INFO_17', 'What do you want show in home page?');
def('INFO_18', 'an application which launchs in your home page');
def('INFO_19', 'query which you want show in home page');
def('INFO_20', 'a piece of HTML or PHP code which launchs in home page.');
def('INFO_21', 'Username must be contain of a-z and 0-9 characters. You can also use dot (.) and underline (_) characters.');
def('INFO_22', 'This username is already exists. Please choose another one.');
def('INFO_23', 'Invalid email address. Please enter another one.');
def('INFO_24', 'This email is already taken by another user. Please choose another one.');
def('INFO_25', 'This role is already exists. Please choose another one.');
def('INFO_26', 'Are you sure you want delete this user account?');
def('INFO_27', 'Are you sure you want delete this widget?');
def('INFO_28', 'There is no installed languages');
def('INFO_29', 'There is no uninstalled languages');
def('INFO_30', 'Are you sure you want to uninstall this language?');
def('INFO_31', 'You do not have enough permission to gain access this page. Please contact the system administrator.');
def('INFO_32', 'Are you sure you want to delete this role and all users in it?');
def('INFO_33', 'Access to this file failed. Please enter your FTP information to update this file using FTP protocol.');
def('INFO_34', 'There is problems that might prevents styles and images working properly:');
def('INFO_35', 'Are you sure you want to load default values for styles and images of this theme?');
def('INFO_36', 'GD Library is not installed.');
def('INFO_37', 'Image files are not writable.');
def('INFO_38', 'Stylesheet file is not writable.');
def('INFO_39', 'Help: Change styles and images permissions to Read and Write for this theme.');
def('INFO_40', 'There is no installed widget');
def('INFO_41', 'Are you sure you want to uninstall this widget?');
def('INFO_42', 'No file is selected.');
def('INFO_43', 'This file is empty.');
def('INFO_44', 'This is not a widget file.');
def('INFO_45', 'This file is not a valid XML file.');
def('INFO_46', 'This file is not a valid Limny widget file.');
def('INFO_47', 'This widget is not compatible with this version of Limny.');
def('INFO_48', 'This widget is already installed.');
def('INFO_49', 'Widget installed successfully.');
def('INFO_50', 'Please confirm uninstall by entering YES.');
def('INFO_51', 'Widget not found.');
def('INFO_52', 'Widget uninstalled successfully.');
def('INFO_53', 'Limny is running with [APP] app[COLLECTOR], [LANGUAGE] language[COLLECTOR], [WIDGET] widget[COLLECTOR] and [USER] user[COLLECTOR] in [ROLE] role[COLLECTOR].');

?>
